# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .http_response_body import HttpResponseBody
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StaticTextHttpResponseBody(HttpResponseBody):
    """
    Allows returning static text as HTTP response body.
    Example:
    {
    \"type\": \"STATIC_TEXT\",
    \"text\": \"{\
    \\\"code\\\": 403,\
    \\\"message\\\":\\\"Unauthorised\\\"\
    }\"
    }
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StaticTextHttpResponseBody object with values from keyword arguments. The default value of the :py:attr:`~oci.waf.models.StaticTextHttpResponseBody.type` attribute
        of this class is ``STATIC_TEXT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this StaticTextHttpResponseBody.
            Allowed values for this property are: "STATIC_TEXT"
        :type type: str

        :param text:
            The value to assign to the text property of this StaticTextHttpResponseBody.
        :type text: str

        """
        self.swagger_types = {
            'type': 'str',
            'text': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'text': 'text'
        }

        self._type = None
        self._text = None
        self._type = 'STATIC_TEXT'

    @property
    def text(self):
        """
        **[Required]** Gets the text of this StaticTextHttpResponseBody.
        Static response body text.


        :return: The text of this StaticTextHttpResponseBody.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this StaticTextHttpResponseBody.
        Static response body text.


        :param text: The text of this StaticTextHttpResponseBody.
        :type: str
        """
        self._text = text

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectPrivilegeSummary(object):
    """
    A summary of object privileges.
    """

    #: A constant which can be used with the hierarchy property of a ObjectPrivilegeSummary.
    #: This constant has a value of "YES"
    HIERARCHY_YES = "YES"

    #: A constant which can be used with the hierarchy property of a ObjectPrivilegeSummary.
    #: This constant has a value of "NO"
    HIERARCHY_NO = "NO"

    #: A constant which can be used with the grant_option property of a ObjectPrivilegeSummary.
    #: This constant has a value of "YES"
    GRANT_OPTION_YES = "YES"

    #: A constant which can be used with the grant_option property of a ObjectPrivilegeSummary.
    #: This constant has a value of "NO"
    GRANT_OPTION_NO = "NO"

    #: A constant which can be used with the common property of a ObjectPrivilegeSummary.
    #: This constant has a value of "YES"
    COMMON_YES = "YES"

    #: A constant which can be used with the common property of a ObjectPrivilegeSummary.
    #: This constant has a value of "NO"
    COMMON_NO = "NO"

    #: A constant which can be used with the inherited property of a ObjectPrivilegeSummary.
    #: This constant has a value of "YES"
    INHERITED_YES = "YES"

    #: A constant which can be used with the inherited property of a ObjectPrivilegeSummary.
    #: This constant has a value of "NO"
    INHERITED_NO = "NO"

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectPrivilegeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ObjectPrivilegeSummary.
        :type name: str

        :param schema_type:
            The value to assign to the schema_type property of this ObjectPrivilegeSummary.
        :type schema_type: str

        :param owner:
            The value to assign to the owner property of this ObjectPrivilegeSummary.
        :type owner: str

        :param grantor:
            The value to assign to the grantor property of this ObjectPrivilegeSummary.
        :type grantor: str

        :param hierarchy:
            The value to assign to the hierarchy property of this ObjectPrivilegeSummary.
            Allowed values for this property are: "YES", "NO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type hierarchy: str

        :param object:
            The value to assign to the object property of this ObjectPrivilegeSummary.
        :type object: str

        :param grant_option:
            The value to assign to the grant_option property of this ObjectPrivilegeSummary.
            Allowed values for this property are: "YES", "NO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type grant_option: str

        :param common:
            The value to assign to the common property of this ObjectPrivilegeSummary.
            Allowed values for this property are: "YES", "NO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type common: str

        :param inherited:
            The value to assign to the inherited property of this ObjectPrivilegeSummary.
            Allowed values for this property are: "YES", "NO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type inherited: str

        """
        self.swagger_types = {
            'name': 'str',
            'schema_type': 'str',
            'owner': 'str',
            'grantor': 'str',
            'hierarchy': 'str',
            'object': 'str',
            'grant_option': 'str',
            'common': 'str',
            'inherited': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'schema_type': 'schemaType',
            'owner': 'owner',
            'grantor': 'grantor',
            'hierarchy': 'hierarchy',
            'object': 'object',
            'grant_option': 'grantOption',
            'common': 'common',
            'inherited': 'inherited'
        }

        self._name = None
        self._schema_type = None
        self._owner = None
        self._grantor = None
        self._hierarchy = None
        self._object = None
        self._grant_option = None
        self._common = None
        self._inherited = None

    @property
    def name(self):
        """
        Gets the name of this ObjectPrivilegeSummary.
        The name of the privilege on the object.


        :return: The name of this ObjectPrivilegeSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ObjectPrivilegeSummary.
        The name of the privilege on the object.


        :param name: The name of this ObjectPrivilegeSummary.
        :type: str
        """
        self._name = name

    @property
    def schema_type(self):
        """
        Gets the schema_type of this ObjectPrivilegeSummary.
        The type of object.


        :return: The schema_type of this ObjectPrivilegeSummary.
        :rtype: str
        """
        return self._schema_type

    @schema_type.setter
    def schema_type(self, schema_type):
        """
        Sets the schema_type of this ObjectPrivilegeSummary.
        The type of object.


        :param schema_type: The schema_type of this ObjectPrivilegeSummary.
        :type: str
        """
        self._schema_type = schema_type

    @property
    def owner(self):
        """
        Gets the owner of this ObjectPrivilegeSummary.
        The owner of the object.


        :return: The owner of this ObjectPrivilegeSummary.
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this ObjectPrivilegeSummary.
        The owner of the object.


        :param owner: The owner of this ObjectPrivilegeSummary.
        :type: str
        """
        self._owner = owner

    @property
    def grantor(self):
        """
        Gets the grantor of this ObjectPrivilegeSummary.
        The name of the user who granted the object privilege.


        :return: The grantor of this ObjectPrivilegeSummary.
        :rtype: str
        """
        return self._grantor

    @grantor.setter
    def grantor(self, grantor):
        """
        Sets the grantor of this ObjectPrivilegeSummary.
        The name of the user who granted the object privilege.


        :param grantor: The grantor of this ObjectPrivilegeSummary.
        :type: str
        """
        self._grantor = grantor

    @property
    def hierarchy(self):
        """
        Gets the hierarchy of this ObjectPrivilegeSummary.
        Indicates whether the privilege is granted with the HIERARCHY OPTION (YES) or not (NO).

        Allowed values for this property are: "YES", "NO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The hierarchy of this ObjectPrivilegeSummary.
        :rtype: str
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """
        Sets the hierarchy of this ObjectPrivilegeSummary.
        Indicates whether the privilege is granted with the HIERARCHY OPTION (YES) or not (NO).


        :param hierarchy: The hierarchy of this ObjectPrivilegeSummary.
        :type: str
        """
        allowed_values = ["YES", "NO"]
        if not value_allowed_none_or_none_sentinel(hierarchy, allowed_values):
            hierarchy = 'UNKNOWN_ENUM_VALUE'
        self._hierarchy = hierarchy

    @property
    def object(self):
        """
        Gets the object of this ObjectPrivilegeSummary.
        The name of the object. The object can be any object, including tables, packages, indexes, sequences, and so on.


        :return: The object of this ObjectPrivilegeSummary.
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """
        Sets the object of this ObjectPrivilegeSummary.
        The name of the object. The object can be any object, including tables, packages, indexes, sequences, and so on.


        :param object: The object of this ObjectPrivilegeSummary.
        :type: str
        """
        self._object = object

    @property
    def grant_option(self):
        """
        Gets the grant_option of this ObjectPrivilegeSummary.
        Indicates whether the privilege is granted with the GRANT OPTION (YES) or not (NO).

        Allowed values for this property are: "YES", "NO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The grant_option of this ObjectPrivilegeSummary.
        :rtype: str
        """
        return self._grant_option

    @grant_option.setter
    def grant_option(self, grant_option):
        """
        Sets the grant_option of this ObjectPrivilegeSummary.
        Indicates whether the privilege is granted with the GRANT OPTION (YES) or not (NO).


        :param grant_option: The grant_option of this ObjectPrivilegeSummary.
        :type: str
        """
        allowed_values = ["YES", "NO"]
        if not value_allowed_none_or_none_sentinel(grant_option, allowed_values):
            grant_option = 'UNKNOWN_ENUM_VALUE'
        self._grant_option = grant_option

    @property
    def common(self):
        """
        Gets the common of this ObjectPrivilegeSummary.
        Indicates how the object privilege was granted. Possible values:
        YES if the role is granted commonly (CONTAINER=ALL is used)
        NO if the role is granted locally (CONTAINER=ALL is not used)

        Allowed values for this property are: "YES", "NO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The common of this ObjectPrivilegeSummary.
        :rtype: str
        """
        return self._common

    @common.setter
    def common(self, common):
        """
        Sets the common of this ObjectPrivilegeSummary.
        Indicates how the object privilege was granted. Possible values:
        YES if the role is granted commonly (CONTAINER=ALL is used)
        NO if the role is granted locally (CONTAINER=ALL is not used)


        :param common: The common of this ObjectPrivilegeSummary.
        :type: str
        """
        allowed_values = ["YES", "NO"]
        if not value_allowed_none_or_none_sentinel(common, allowed_values):
            common = 'UNKNOWN_ENUM_VALUE'
        self._common = common

    @property
    def inherited(self):
        """
        Gets the inherited of this ObjectPrivilegeSummary.
        Indicates whether the granted privilege is inherited from another container (YES) or not (NO).

        Allowed values for this property are: "YES", "NO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The inherited of this ObjectPrivilegeSummary.
        :rtype: str
        """
        return self._inherited

    @inherited.setter
    def inherited(self, inherited):
        """
        Sets the inherited of this ObjectPrivilegeSummary.
        Indicates whether the granted privilege is inherited from another container (YES) or not (NO).


        :param inherited: The inherited of this ObjectPrivilegeSummary.
        :type: str
        """
        allowed_values = ["YES", "NO"]
        if not value_allowed_none_or_none_sentinel(inherited, allowed_values):
            inherited = 'UNKNOWN_ENUM_VALUE'
        self._inherited = inherited

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RepositoryPathSummary(object):
    """
    Object containing information about files and directories in a repository.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RepositoryPathSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this RepositoryPathSummary.
        :type type: str

        :param size_in_bytes:
            The value to assign to the size_in_bytes property of this RepositoryPathSummary.
        :type size_in_bytes: int

        :param name:
            The value to assign to the name property of this RepositoryPathSummary.
        :type name: str

        :param path:
            The value to assign to the path property of this RepositoryPathSummary.
        :type path: str

        :param sha:
            The value to assign to the sha property of this RepositoryPathSummary.
        :type sha: str

        :param submodule_git_url:
            The value to assign to the submodule_git_url property of this RepositoryPathSummary.
        :type submodule_git_url: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this RepositoryPathSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this RepositoryPathSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'type': 'str',
            'size_in_bytes': 'int',
            'name': 'str',
            'path': 'str',
            'sha': 'str',
            'submodule_git_url': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'type': 'type',
            'size_in_bytes': 'sizeInBytes',
            'name': 'name',
            'path': 'path',
            'sha': 'sha',
            'submodule_git_url': 'submoduleGitUrl',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._type = None
        self._size_in_bytes = None
        self._name = None
        self._path = None
        self._sha = None
        self._submodule_git_url = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def type(self):
        """
        Gets the type of this RepositoryPathSummary.
        File or directory.


        :return: The type of this RepositoryPathSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this RepositoryPathSummary.
        File or directory.


        :param type: The type of this RepositoryPathSummary.
        :type: str
        """
        self._type = type

    @property
    def size_in_bytes(self):
        """
        Gets the size_in_bytes of this RepositoryPathSummary.
        Size of file or directory.


        :return: The size_in_bytes of this RepositoryPathSummary.
        :rtype: int
        """
        return self._size_in_bytes

    @size_in_bytes.setter
    def size_in_bytes(self, size_in_bytes):
        """
        Sets the size_in_bytes of this RepositoryPathSummary.
        Size of file or directory.


        :param size_in_bytes: The size_in_bytes of this RepositoryPathSummary.
        :type: int
        """
        self._size_in_bytes = size_in_bytes

    @property
    def name(self):
        """
        Gets the name of this RepositoryPathSummary.
        Name of file or directory.


        :return: The name of this RepositoryPathSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this RepositoryPathSummary.
        Name of file or directory.


        :param name: The name of this RepositoryPathSummary.
        :type: str
        """
        self._name = name

    @property
    def path(self):
        """
        Gets the path of this RepositoryPathSummary.
        Path to file or directory in a repository.


        :return: The path of this RepositoryPathSummary.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this RepositoryPathSummary.
        Path to file or directory in a repository.


        :param path: The path of this RepositoryPathSummary.
        :type: str
        """
        self._path = path

    @property
    def sha(self):
        """
        Gets the sha of this RepositoryPathSummary.
        SHA-1 checksum of blob or tree.


        :return: The sha of this RepositoryPathSummary.
        :rtype: str
        """
        return self._sha

    @sha.setter
    def sha(self, sha):
        """
        Sets the sha of this RepositoryPathSummary.
        SHA-1 checksum of blob or tree.


        :param sha: The sha of this RepositoryPathSummary.
        :type: str
        """
        self._sha = sha

    @property
    def submodule_git_url(self):
        """
        Gets the submodule_git_url of this RepositoryPathSummary.
        The git URL of the submodule.


        :return: The submodule_git_url of this RepositoryPathSummary.
        :rtype: str
        """
        return self._submodule_git_url

    @submodule_git_url.setter
    def submodule_git_url(self, submodule_git_url):
        """
        Sets the submodule_git_url of this RepositoryPathSummary.
        The git URL of the submodule.


        :param submodule_git_url: The submodule_git_url of this RepositoryPathSummary.
        :type: str
        """
        self._submodule_git_url = submodule_git_url

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this RepositoryPathSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this RepositoryPathSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this RepositoryPathSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this RepositoryPathSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this RepositoryPathSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this RepositoryPathSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this RepositoryPathSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this RepositoryPathSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_trigger_details import UpdateTriggerDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDevopsCodeRepositoryTriggerDetails(UpdateTriggerDetails):
    """
    Update trigger specific to OCI DevOps code repository.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDevopsCodeRepositoryTriggerDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.UpdateDevopsCodeRepositoryTriggerDetails.trigger_source` attribute
        of this class is ``DEVOPS_CODE_REPOSITORY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateDevopsCodeRepositoryTriggerDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdateDevopsCodeRepositoryTriggerDetails.
        :type description: str

        :param trigger_source:
            The value to assign to the trigger_source property of this UpdateDevopsCodeRepositoryTriggerDetails.
        :type trigger_source: str

        :param actions:
            The value to assign to the actions property of this UpdateDevopsCodeRepositoryTriggerDetails.
        :type actions: list[oci.devops.models.TriggerAction]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateDevopsCodeRepositoryTriggerDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateDevopsCodeRepositoryTriggerDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param repository_id:
            The value to assign to the repository_id property of this UpdateDevopsCodeRepositoryTriggerDetails.
        :type repository_id: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'trigger_source': 'str',
            'actions': 'list[TriggerAction]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'repository_id': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'trigger_source': 'triggerSource',
            'actions': 'actions',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'repository_id': 'repositoryId'
        }

        self._display_name = None
        self._description = None
        self._trigger_source = None
        self._actions = None
        self._freeform_tags = None
        self._defined_tags = None
        self._repository_id = None
        self._trigger_source = 'DEVOPS_CODE_REPOSITORY'

    @property
    def repository_id(self):
        """
        Gets the repository_id of this UpdateDevopsCodeRepositoryTriggerDetails.
        The OCID of the DevOps code repository.


        :return: The repository_id of this UpdateDevopsCodeRepositoryTriggerDetails.
        :rtype: str
        """
        return self._repository_id

    @repository_id.setter
    def repository_id(self, repository_id):
        """
        Sets the repository_id of this UpdateDevopsCodeRepositoryTriggerDetails.
        The OCID of the DevOps code repository.


        :param repository_id: The repository_id of this UpdateDevopsCodeRepositoryTriggerDetails.
        :type: str
        """
        self._repository_id = repository_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .ca_bundle import CaBundle
from .certificate_authority_bundle import CertificateAuthorityBundle
from .certificate_authority_bundle_version_collection import CertificateAuthorityBundleVersionCollection
from .certificate_authority_bundle_version_summary import CertificateAuthorityBundleVersionSummary
from .certificate_bundle import CertificateBundle
from .certificate_bundle_public_only import CertificateBundlePublicOnly
from .certificate_bundle_version_collection import CertificateBundleVersionCollection
from .certificate_bundle_version_summary import CertificateBundleVersionSummary
from .certificate_bundle_with_private_key import CertificateBundleWithPrivateKey
from .revocation_status import RevocationStatus
from .validity import Validity

# Maps type names to classes for certificates services.
certificates_type_mapping = {
    "CaBundle": CaBundle,
    "CertificateAuthorityBundle": CertificateAuthorityBundle,
    "CertificateAuthorityBundleVersionCollection": CertificateAuthorityBundleVersionCollection,
    "CertificateAuthorityBundleVersionSummary": CertificateAuthorityBundleVersionSummary,
    "CertificateBundle": CertificateBundle,
    "CertificateBundlePublicOnly": CertificateBundlePublicOnly,
    "CertificateBundleVersionCollection": CertificateBundleVersionCollection,
    "CertificateBundleVersionSummary": CertificateBundleVersionSummary,
    "CertificateBundleWithPrivateKey": CertificateBundleWithPrivateKey,
    "RevocationStatus": RevocationStatus,
    "Validity": Validity
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MaskingColumnSummary(object):
    """
    Summary of a masking column.
    """

    #: A constant which can be used with the lifecycle_state property of a MaskingColumnSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a MaskingColumnSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a MaskingColumnSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a MaskingColumnSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a MaskingColumnSummary.
    #: This constant has a value of "NEEDS_ATTENTION"
    LIFECYCLE_STATE_NEEDS_ATTENTION = "NEEDS_ATTENTION"

    #: A constant which can be used with the lifecycle_state property of a MaskingColumnSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the object_type property of a MaskingColumnSummary.
    #: This constant has a value of "TABLE"
    OBJECT_TYPE_TABLE = "TABLE"

    #: A constant which can be used with the object_type property of a MaskingColumnSummary.
    #: This constant has a value of "EDITIONING_VIEW"
    OBJECT_TYPE_EDITIONING_VIEW = "EDITIONING_VIEW"

    def __init__(self, **kwargs):
        """
        Initializes a new MaskingColumnSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this MaskingColumnSummary.
        :type key: str

        :param masking_policy_id:
            The value to assign to the masking_policy_id property of this MaskingColumnSummary.
        :type masking_policy_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this MaskingColumnSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "NEEDS_ATTENTION", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this MaskingColumnSummary.
        :type lifecycle_details: str

        :param time_created:
            The value to assign to the time_created property of this MaskingColumnSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this MaskingColumnSummary.
        :type time_updated: datetime

        :param schema_name:
            The value to assign to the schema_name property of this MaskingColumnSummary.
        :type schema_name: str

        :param object_name:
            The value to assign to the object_name property of this MaskingColumnSummary.
        :type object_name: str

        :param object_type:
            The value to assign to the object_type property of this MaskingColumnSummary.
            Allowed values for this property are: "TABLE", "EDITIONING_VIEW", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type object_type: str

        :param column_name:
            The value to assign to the column_name property of this MaskingColumnSummary.
        :type column_name: str

        :param child_columns:
            The value to assign to the child_columns property of this MaskingColumnSummary.
        :type child_columns: list[str]

        :param masking_column_group:
            The value to assign to the masking_column_group property of this MaskingColumnSummary.
        :type masking_column_group: str

        :param sensitive_type_id:
            The value to assign to the sensitive_type_id property of this MaskingColumnSummary.
        :type sensitive_type_id: str

        :param is_masking_enabled:
            The value to assign to the is_masking_enabled property of this MaskingColumnSummary.
        :type is_masking_enabled: bool

        :param data_type:
            The value to assign to the data_type property of this MaskingColumnSummary.
        :type data_type: str

        :param masking_formats:
            The value to assign to the masking_formats property of this MaskingColumnSummary.
        :type masking_formats: list[oci.data_safe.models.MaskingFormat]

        """
        self.swagger_types = {
            'key': 'str',
            'masking_policy_id': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'schema_name': 'str',
            'object_name': 'str',
            'object_type': 'str',
            'column_name': 'str',
            'child_columns': 'list[str]',
            'masking_column_group': 'str',
            'sensitive_type_id': 'str',
            'is_masking_enabled': 'bool',
            'data_type': 'str',
            'masking_formats': 'list[MaskingFormat]'
        }

        self.attribute_map = {
            'key': 'key',
            'masking_policy_id': 'maskingPolicyId',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'schema_name': 'schemaName',
            'object_name': 'objectName',
            'object_type': 'objectType',
            'column_name': 'columnName',
            'child_columns': 'childColumns',
            'masking_column_group': 'maskingColumnGroup',
            'sensitive_type_id': 'sensitiveTypeId',
            'is_masking_enabled': 'isMaskingEnabled',
            'data_type': 'dataType',
            'masking_formats': 'maskingFormats'
        }

        self._key = None
        self._masking_policy_id = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_created = None
        self._time_updated = None
        self._schema_name = None
        self._object_name = None
        self._object_type = None
        self._column_name = None
        self._child_columns = None
        self._masking_column_group = None
        self._sensitive_type_id = None
        self._is_masking_enabled = None
        self._data_type = None
        self._masking_formats = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this MaskingColumnSummary.
        The unique key that identifies a masking column. The key is numeric and unique within a masking policy.


        :return: The key of this MaskingColumnSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this MaskingColumnSummary.
        The unique key that identifies a masking column. The key is numeric and unique within a masking policy.


        :param key: The key of this MaskingColumnSummary.
        :type: str
        """
        self._key = key

    @property
    def masking_policy_id(self):
        """
        **[Required]** Gets the masking_policy_id of this MaskingColumnSummary.
        The OCID of the masking policy that contains the masking column.


        :return: The masking_policy_id of this MaskingColumnSummary.
        :rtype: str
        """
        return self._masking_policy_id

    @masking_policy_id.setter
    def masking_policy_id(self, masking_policy_id):
        """
        Sets the masking_policy_id of this MaskingColumnSummary.
        The OCID of the masking policy that contains the masking column.


        :param masking_policy_id: The masking_policy_id of this MaskingColumnSummary.
        :type: str
        """
        self._masking_policy_id = masking_policy_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this MaskingColumnSummary.
        The current state of the masking column.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "NEEDS_ATTENTION", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this MaskingColumnSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this MaskingColumnSummary.
        The current state of the masking column.


        :param lifecycle_state: The lifecycle_state of this MaskingColumnSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "DELETING", "NEEDS_ATTENTION", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this MaskingColumnSummary.
        Details about the current state of the masking column.


        :return: The lifecycle_details of this MaskingColumnSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this MaskingColumnSummary.
        Details about the current state of the masking column.


        :param lifecycle_details: The lifecycle_details of this MaskingColumnSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this MaskingColumnSummary.
        The date and time the masking column was created, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this MaskingColumnSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this MaskingColumnSummary.
        The date and time the masking column was created, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this MaskingColumnSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this MaskingColumnSummary.
        The date and time the masking column was last updated, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this MaskingColumnSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this MaskingColumnSummary.
        The date and time the masking column was last updated, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this MaskingColumnSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def schema_name(self):
        """
        **[Required]** Gets the schema_name of this MaskingColumnSummary.
        The name of the schema that contains the database column.


        :return: The schema_name of this MaskingColumnSummary.
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """
        Sets the schema_name of this MaskingColumnSummary.
        The name of the schema that contains the database column.


        :param schema_name: The schema_name of this MaskingColumnSummary.
        :type: str
        """
        self._schema_name = schema_name

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this MaskingColumnSummary.
        The name of the object (table or editioning view) that contains the database column.


        :return: The object_name of this MaskingColumnSummary.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this MaskingColumnSummary.
        The name of the object (table or editioning view) that contains the database column.


        :param object_name: The object_name of this MaskingColumnSummary.
        :type: str
        """
        self._object_name = object_name

    @property
    def object_type(self):
        """
        Gets the object_type of this MaskingColumnSummary.
        The type of the object that contains the database column.

        Allowed values for this property are: "TABLE", "EDITIONING_VIEW", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The object_type of this MaskingColumnSummary.
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """
        Sets the object_type of this MaskingColumnSummary.
        The type of the object that contains the database column.


        :param object_type: The object_type of this MaskingColumnSummary.
        :type: str
        """
        allowed_values = ["TABLE", "EDITIONING_VIEW"]
        if not value_allowed_none_or_none_sentinel(object_type, allowed_values):
            object_type = 'UNKNOWN_ENUM_VALUE'
        self._object_type = object_type

    @property
    def column_name(self):
        """
        **[Required]** Gets the column_name of this MaskingColumnSummary.
        The name of the database column. Note that the same name is used for the masking column.
        There is no separate displayName attribute for the masking column.


        :return: The column_name of this MaskingColumnSummary.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this MaskingColumnSummary.
        The name of the database column. Note that the same name is used for the masking column.
        There is no separate displayName attribute for the masking column.


        :param column_name: The column_name of this MaskingColumnSummary.
        :type: str
        """
        self._column_name = column_name

    @property
    def child_columns(self):
        """
        Gets the child_columns of this MaskingColumnSummary.
        An array of child columns that are in referential relationship with the masking column.


        :return: The child_columns of this MaskingColumnSummary.
        :rtype: list[str]
        """
        return self._child_columns

    @child_columns.setter
    def child_columns(self, child_columns):
        """
        Sets the child_columns of this MaskingColumnSummary.
        An array of child columns that are in referential relationship with the masking column.


        :param child_columns: The child_columns of this MaskingColumnSummary.
        :type: list[str]
        """
        self._child_columns = child_columns

    @property
    def masking_column_group(self):
        """
        Gets the masking_column_group of this MaskingColumnSummary.
        The group of the masking column. All the columns in a group are masked together to ensure
        that the masked data across these columns continue
        to retain the same logical relationship. For more details, check <a href=https://docs.oracle.com/en/cloud/paas/data-safe/udscs/group-masking1.html#GUID-755056B9-9540-48C0-9491-262A44A85037>Group Masking in the Data Safe documentation.</a>


        :return: The masking_column_group of this MaskingColumnSummary.
        :rtype: str
        """
        return self._masking_column_group

    @masking_column_group.setter
    def masking_column_group(self, masking_column_group):
        """
        Sets the masking_column_group of this MaskingColumnSummary.
        The group of the masking column. All the columns in a group are masked together to ensure
        that the masked data across these columns continue
        to retain the same logical relationship. For more details, check <a href=https://docs.oracle.com/en/cloud/paas/data-safe/udscs/group-masking1.html#GUID-755056B9-9540-48C0-9491-262A44A85037>Group Masking in the Data Safe documentation.</a>


        :param masking_column_group: The masking_column_group of this MaskingColumnSummary.
        :type: str
        """
        self._masking_column_group = masking_column_group

    @property
    def sensitive_type_id(self):
        """
        Gets the sensitive_type_id of this MaskingColumnSummary.
        The OCID of the sensitive type associated with the masking column.


        :return: The sensitive_type_id of this MaskingColumnSummary.
        :rtype: str
        """
        return self._sensitive_type_id

    @sensitive_type_id.setter
    def sensitive_type_id(self, sensitive_type_id):
        """
        Sets the sensitive_type_id of this MaskingColumnSummary.
        The OCID of the sensitive type associated with the masking column.


        :param sensitive_type_id: The sensitive_type_id of this MaskingColumnSummary.
        :type: str
        """
        self._sensitive_type_id = sensitive_type_id

    @property
    def is_masking_enabled(self):
        """
        **[Required]** Gets the is_masking_enabled of this MaskingColumnSummary.
        Indicates if data masking is enabled for the masking column.


        :return: The is_masking_enabled of this MaskingColumnSummary.
        :rtype: bool
        """
        return self._is_masking_enabled

    @is_masking_enabled.setter
    def is_masking_enabled(self, is_masking_enabled):
        """
        Sets the is_masking_enabled of this MaskingColumnSummary.
        Indicates if data masking is enabled for the masking column.


        :param is_masking_enabled: The is_masking_enabled of this MaskingColumnSummary.
        :type: bool
        """
        self._is_masking_enabled = is_masking_enabled

    @property
    def data_type(self):
        """
        Gets the data_type of this MaskingColumnSummary.
        The data type of the masking column.


        :return: The data_type of this MaskingColumnSummary.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this MaskingColumnSummary.
        The data type of the masking column.


        :param data_type: The data_type of this MaskingColumnSummary.
        :type: str
        """
        self._data_type = data_type

    @property
    def masking_formats(self):
        """
        Gets the masking_formats of this MaskingColumnSummary.
        An array of masking formats assigned to the masking column.


        :return: The masking_formats of this MaskingColumnSummary.
        :rtype: list[oci.data_safe.models.MaskingFormat]
        """
        return self._masking_formats

    @masking_formats.setter
    def masking_formats(self, masking_formats):
        """
        Sets the masking_formats of this MaskingColumnSummary.
        An array of masking formats assigned to the masking column.


        :param masking_formats: The masking_formats of this MaskingColumnSummary.
        :type: list[oci.data_safe.models.MaskingFormat]
        """
        self._masking_formats = masking_formats

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnalyzeDocumentDetails(object):
    """
    The details of how to analyze a document.
    """

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "ENG"
    LANGUAGE_ENG = "ENG"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "CES"
    LANGUAGE_CES = "CES"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "DAN"
    LANGUAGE_DAN = "DAN"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "NLD"
    LANGUAGE_NLD = "NLD"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "FIN"
    LANGUAGE_FIN = "FIN"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "FRA"
    LANGUAGE_FRA = "FRA"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "DEU"
    LANGUAGE_DEU = "DEU"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "ELL"
    LANGUAGE_ELL = "ELL"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "HUN"
    LANGUAGE_HUN = "HUN"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "ITA"
    LANGUAGE_ITA = "ITA"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "NOR"
    LANGUAGE_NOR = "NOR"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "POL"
    LANGUAGE_POL = "POL"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "POR"
    LANGUAGE_POR = "POR"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "RON"
    LANGUAGE_RON = "RON"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "RUS"
    LANGUAGE_RUS = "RUS"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "SLK"
    LANGUAGE_SLK = "SLK"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "SPA"
    LANGUAGE_SPA = "SPA"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "SWE"
    LANGUAGE_SWE = "SWE"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "TUR"
    LANGUAGE_TUR = "TUR"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "ARA"
    LANGUAGE_ARA = "ARA"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "CHI_SIM"
    LANGUAGE_CHI_SIM = "CHI_SIM"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "HIN"
    LANGUAGE_HIN = "HIN"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "JPN"
    LANGUAGE_JPN = "JPN"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "KOR"
    LANGUAGE_KOR = "KOR"

    #: A constant which can be used with the language property of a AnalyzeDocumentDetails.
    #: This constant has a value of "OTHERS"
    LANGUAGE_OTHERS = "OTHERS"

    #: A constant which can be used with the document_type property of a AnalyzeDocumentDetails.
    #: This constant has a value of "INVOICE"
    DOCUMENT_TYPE_INVOICE = "INVOICE"

    #: A constant which can be used with the document_type property of a AnalyzeDocumentDetails.
    #: This constant has a value of "RECEIPT"
    DOCUMENT_TYPE_RECEIPT = "RECEIPT"

    #: A constant which can be used with the document_type property of a AnalyzeDocumentDetails.
    #: This constant has a value of "RESUME"
    DOCUMENT_TYPE_RESUME = "RESUME"

    #: A constant which can be used with the document_type property of a AnalyzeDocumentDetails.
    #: This constant has a value of "TAX_FORM"
    DOCUMENT_TYPE_TAX_FORM = "TAX_FORM"

    #: A constant which can be used with the document_type property of a AnalyzeDocumentDetails.
    #: This constant has a value of "DRIVER_LICENSE"
    DOCUMENT_TYPE_DRIVER_LICENSE = "DRIVER_LICENSE"

    #: A constant which can be used with the document_type property of a AnalyzeDocumentDetails.
    #: This constant has a value of "PASSPORT"
    DOCUMENT_TYPE_PASSPORT = "PASSPORT"

    #: A constant which can be used with the document_type property of a AnalyzeDocumentDetails.
    #: This constant has a value of "BANK_STATEMENT"
    DOCUMENT_TYPE_BANK_STATEMENT = "BANK_STATEMENT"

    #: A constant which can be used with the document_type property of a AnalyzeDocumentDetails.
    #: This constant has a value of "CHECK"
    DOCUMENT_TYPE_CHECK = "CHECK"

    #: A constant which can be used with the document_type property of a AnalyzeDocumentDetails.
    #: This constant has a value of "PAYSLIP"
    DOCUMENT_TYPE_PAYSLIP = "PAYSLIP"

    #: A constant which can be used with the document_type property of a AnalyzeDocumentDetails.
    #: This constant has a value of "OTHERS"
    DOCUMENT_TYPE_OTHERS = "OTHERS"

    def __init__(self, **kwargs):
        """
        Initializes a new AnalyzeDocumentDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param features:
            The value to assign to the features property of this AnalyzeDocumentDetails.
        :type features: list[oci.ai_vision.models.DocumentFeature]

        :param document:
            The value to assign to the document property of this AnalyzeDocumentDetails.
        :type document: oci.ai_vision.models.DocumentDetails

        :param compartment_id:
            The value to assign to the compartment_id property of this AnalyzeDocumentDetails.
        :type compartment_id: str

        :param output_location:
            The value to assign to the output_location property of this AnalyzeDocumentDetails.
        :type output_location: oci.ai_vision.models.OutputLocation

        :param language:
            The value to assign to the language property of this AnalyzeDocumentDetails.
            Allowed values for this property are: "ENG", "CES", "DAN", "NLD", "FIN", "FRA", "DEU", "ELL", "HUN", "ITA", "NOR", "POL", "POR", "RON", "RUS", "SLK", "SPA", "SWE", "TUR", "ARA", "CHI_SIM", "HIN", "JPN", "KOR", "OTHERS"
        :type language: str

        :param document_type:
            The value to assign to the document_type property of this AnalyzeDocumentDetails.
            Allowed values for this property are: "INVOICE", "RECEIPT", "RESUME", "TAX_FORM", "DRIVER_LICENSE", "PASSPORT", "BANK_STATEMENT", "CHECK", "PAYSLIP", "OTHERS"
        :type document_type: str

        """
        self.swagger_types = {
            'features': 'list[DocumentFeature]',
            'document': 'DocumentDetails',
            'compartment_id': 'str',
            'output_location': 'OutputLocation',
            'language': 'str',
            'document_type': 'str'
        }

        self.attribute_map = {
            'features': 'features',
            'document': 'document',
            'compartment_id': 'compartmentId',
            'output_location': 'outputLocation',
            'language': 'language',
            'document_type': 'documentType'
        }

        self._features = None
        self._document = None
        self._compartment_id = None
        self._output_location = None
        self._language = None
        self._document_type = None

    @property
    def features(self):
        """
        **[Required]** Gets the features of this AnalyzeDocumentDetails.
        The types of document analysis requested.


        :return: The features of this AnalyzeDocumentDetails.
        :rtype: list[oci.ai_vision.models.DocumentFeature]
        """
        return self._features

    @features.setter
    def features(self, features):
        """
        Sets the features of this AnalyzeDocumentDetails.
        The types of document analysis requested.


        :param features: The features of this AnalyzeDocumentDetails.
        :type: list[oci.ai_vision.models.DocumentFeature]
        """
        self._features = features

    @property
    def document(self):
        """
        **[Required]** Gets the document of this AnalyzeDocumentDetails.

        :return: The document of this AnalyzeDocumentDetails.
        :rtype: oci.ai_vision.models.DocumentDetails
        """
        return self._document

    @document.setter
    def document(self, document):
        """
        Sets the document of this AnalyzeDocumentDetails.

        :param document: The document of this AnalyzeDocumentDetails.
        :type: oci.ai_vision.models.DocumentDetails
        """
        self._document = document

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this AnalyzeDocumentDetails.
        The OCID of the compartment that calls the API.


        :return: The compartment_id of this AnalyzeDocumentDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AnalyzeDocumentDetails.
        The OCID of the compartment that calls the API.


        :param compartment_id: The compartment_id of this AnalyzeDocumentDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def output_location(self):
        """
        Gets the output_location of this AnalyzeDocumentDetails.

        :return: The output_location of this AnalyzeDocumentDetails.
        :rtype: oci.ai_vision.models.OutputLocation
        """
        return self._output_location

    @output_location.setter
    def output_location(self, output_location):
        """
        Sets the output_location of this AnalyzeDocumentDetails.

        :param output_location: The output_location of this AnalyzeDocumentDetails.
        :type: oci.ai_vision.models.OutputLocation
        """
        self._output_location = output_location

    @property
    def language(self):
        """
        Gets the language of this AnalyzeDocumentDetails.
        The document language, abbreviated according to ISO 639-2.

        Allowed values for this property are: "ENG", "CES", "DAN", "NLD", "FIN", "FRA", "DEU", "ELL", "HUN", "ITA", "NOR", "POL", "POR", "RON", "RUS", "SLK", "SPA", "SWE", "TUR", "ARA", "CHI_SIM", "HIN", "JPN", "KOR", "OTHERS"


        :return: The language of this AnalyzeDocumentDetails.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this AnalyzeDocumentDetails.
        The document language, abbreviated according to ISO 639-2.


        :param language: The language of this AnalyzeDocumentDetails.
        :type: str
        """
        allowed_values = ["ENG", "CES", "DAN", "NLD", "FIN", "FRA", "DEU", "ELL", "HUN", "ITA", "NOR", "POL", "POR", "RON", "RUS", "SLK", "SPA", "SWE", "TUR", "ARA", "CHI_SIM", "HIN", "JPN", "KOR", "OTHERS"]
        if not value_allowed_none_or_none_sentinel(language, allowed_values):
            raise ValueError(
                "Invalid value for `language`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._language = language

    @property
    def document_type(self):
        """
        Gets the document_type of this AnalyzeDocumentDetails.
        The document type.

        Allowed values for this property are: "INVOICE", "RECEIPT", "RESUME", "TAX_FORM", "DRIVER_LICENSE", "PASSPORT", "BANK_STATEMENT", "CHECK", "PAYSLIP", "OTHERS"


        :return: The document_type of this AnalyzeDocumentDetails.
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """
        Sets the document_type of this AnalyzeDocumentDetails.
        The document type.


        :param document_type: The document_type of this AnalyzeDocumentDetails.
        :type: str
        """
        allowed_values = ["INVOICE", "RECEIPT", "RESUME", "TAX_FORM", "DRIVER_LICENSE", "PASSPORT", "BANK_STATEMENT", "CHECK", "PAYSLIP", "OTHERS"]
        if not value_allowed_none_or_none_sentinel(document_type, allowed_values):
            raise ValueError(
                "Invalid value for `document_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._document_type = document_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ModuleStreamProfileDetails(object):
    """
    Updatable information for a module stream profile
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ModuleStreamProfileDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param module_name:
            The value to assign to the module_name property of this ModuleStreamProfileDetails.
        :type module_name: str

        :param stream_name:
            The value to assign to the stream_name property of this ModuleStreamProfileDetails.
        :type stream_name: str

        :param profile_name:
            The value to assign to the profile_name property of this ModuleStreamProfileDetails.
        :type profile_name: str

        """
        self.swagger_types = {
            'module_name': 'str',
            'stream_name': 'str',
            'profile_name': 'str'
        }

        self.attribute_map = {
            'module_name': 'moduleName',
            'stream_name': 'streamName',
            'profile_name': 'profileName'
        }

        self._module_name = None
        self._stream_name = None
        self._profile_name = None

    @property
    def module_name(self):
        """
        **[Required]** Gets the module_name of this ModuleStreamProfileDetails.
        The name of a module


        :return: The module_name of this ModuleStreamProfileDetails.
        :rtype: str
        """
        return self._module_name

    @module_name.setter
    def module_name(self, module_name):
        """
        Sets the module_name of this ModuleStreamProfileDetails.
        The name of a module


        :param module_name: The module_name of this ModuleStreamProfileDetails.
        :type: str
        """
        self._module_name = module_name

    @property
    def stream_name(self):
        """
        **[Required]** Gets the stream_name of this ModuleStreamProfileDetails.
        The name of a stream of the specified module


        :return: The stream_name of this ModuleStreamProfileDetails.
        :rtype: str
        """
        return self._stream_name

    @stream_name.setter
    def stream_name(self, stream_name):
        """
        Sets the stream_name of this ModuleStreamProfileDetails.
        The name of a stream of the specified module


        :param stream_name: The stream_name of this ModuleStreamProfileDetails.
        :type: str
        """
        self._stream_name = stream_name

    @property
    def profile_name(self):
        """
        **[Required]** Gets the profile_name of this ModuleStreamProfileDetails.
        The name of a profile of the specified module stream


        :return: The profile_name of this ModuleStreamProfileDetails.
        :rtype: str
        """
        return self._profile_name

    @profile_name.setter
    def profile_name(self, profile_name):
        """
        Sets the profile_name of this ModuleStreamProfileDetails.
        The name of a profile of the specified module stream


        :param profile_name: The profile_name of this ModuleStreamProfileDetails.
        :type: str
        """
        self._profile_name = profile_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PeComanagedDatabaseConnectionDetails(object):
    """
    Connection details of the private endpoints.
    """

    #: A constant which can be used with the protocol property of a PeComanagedDatabaseConnectionDetails.
    #: This constant has a value of "TCP"
    PROTOCOL_TCP = "TCP"

    #: A constant which can be used with the protocol property of a PeComanagedDatabaseConnectionDetails.
    #: This constant has a value of "TCPS"
    PROTOCOL_TCPS = "TCPS"

    def __init__(self, **kwargs):
        """
        Initializes a new PeComanagedDatabaseConnectionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param hosts:
            The value to assign to the hosts property of this PeComanagedDatabaseConnectionDetails.
        :type hosts: list[oci.opsi.models.PeComanagedDatabaseHostDetails]

        :param protocol:
            The value to assign to the protocol property of this PeComanagedDatabaseConnectionDetails.
            Allowed values for this property are: "TCP", "TCPS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type protocol: str

        :param service_name:
            The value to assign to the service_name property of this PeComanagedDatabaseConnectionDetails.
        :type service_name: str

        """
        self.swagger_types = {
            'hosts': 'list[PeComanagedDatabaseHostDetails]',
            'protocol': 'str',
            'service_name': 'str'
        }

        self.attribute_map = {
            'hosts': 'hosts',
            'protocol': 'protocol',
            'service_name': 'serviceName'
        }

        self._hosts = None
        self._protocol = None
        self._service_name = None

    @property
    def hosts(self):
        """
        **[Required]** Gets the hosts of this PeComanagedDatabaseConnectionDetails.
        List of hosts and port for private endpoint accessed database resource.


        :return: The hosts of this PeComanagedDatabaseConnectionDetails.
        :rtype: list[oci.opsi.models.PeComanagedDatabaseHostDetails]
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """
        Sets the hosts of this PeComanagedDatabaseConnectionDetails.
        List of hosts and port for private endpoint accessed database resource.


        :param hosts: The hosts of this PeComanagedDatabaseConnectionDetails.
        :type: list[oci.opsi.models.PeComanagedDatabaseHostDetails]
        """
        self._hosts = hosts

    @property
    def protocol(self):
        """
        Gets the protocol of this PeComanagedDatabaseConnectionDetails.
        Protocol used for connection requests for private endpoint accssed database resource.

        Allowed values for this property are: "TCP", "TCPS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The protocol of this PeComanagedDatabaseConnectionDetails.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this PeComanagedDatabaseConnectionDetails.
        Protocol used for connection requests for private endpoint accssed database resource.


        :param protocol: The protocol of this PeComanagedDatabaseConnectionDetails.
        :type: str
        """
        allowed_values = ["TCP", "TCPS"]
        if not value_allowed_none_or_none_sentinel(protocol, allowed_values):
            protocol = 'UNKNOWN_ENUM_VALUE'
        self._protocol = protocol

    @property
    def service_name(self):
        """
        Gets the service_name of this PeComanagedDatabaseConnectionDetails.
        Database service name used for connection requests.


        :return: The service_name of this PeComanagedDatabaseConnectionDetails.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this PeComanagedDatabaseConnectionDetails.
        Database service name used for connection requests.


        :param service_name: The service_name of this PeComanagedDatabaseConnectionDetails.
        :type: str
        """
        self._service_name = service_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateUserDefinedFunctionDetails(object):
    """
    Properties used in user defined function update operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateUserDefinedFunctionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param parent_ref:
            The value to assign to the parent_ref property of this UpdateUserDefinedFunctionDetails.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this UpdateUserDefinedFunctionDetails.
        :type name: str

        :param identifier:
            The value to assign to the identifier property of this UpdateUserDefinedFunctionDetails.
        :type identifier: str

        :param model_version:
            The value to assign to the model_version property of this UpdateUserDefinedFunctionDetails.
        :type model_version: str

        :param object_version:
            The value to assign to the object_version property of this UpdateUserDefinedFunctionDetails.
        :type object_version: int

        :param signatures:
            The value to assign to the signatures property of this UpdateUserDefinedFunctionDetails.
        :type signatures: list[oci.data_integration.models.FunctionSignature]

        :param expr:
            The value to assign to the expr property of this UpdateUserDefinedFunctionDetails.
        :type expr: oci.data_integration.models.Expression

        :param description:
            The value to assign to the description property of this UpdateUserDefinedFunctionDetails.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this UpdateUserDefinedFunctionDetails.
        :type object_status: int

        :param registry_metadata:
            The value to assign to the registry_metadata property of this UpdateUserDefinedFunctionDetails.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        """
        self.swagger_types = {
            'parent_ref': 'ParentReference',
            'name': 'str',
            'identifier': 'str',
            'model_version': 'str',
            'object_version': 'int',
            'signatures': 'list[FunctionSignature]',
            'expr': 'Expression',
            'description': 'str',
            'object_status': 'int',
            'registry_metadata': 'RegistryMetadata'
        }

        self.attribute_map = {
            'parent_ref': 'parentRef',
            'name': 'name',
            'identifier': 'identifier',
            'model_version': 'modelVersion',
            'object_version': 'objectVersion',
            'signatures': 'signatures',
            'expr': 'expr',
            'description': 'description',
            'object_status': 'objectStatus',
            'registry_metadata': 'registryMetadata'
        }

        self._parent_ref = None
        self._name = None
        self._identifier = None
        self._model_version = None
        self._object_version = None
        self._signatures = None
        self._expr = None
        self._description = None
        self._object_status = None
        self._registry_metadata = None

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this UpdateUserDefinedFunctionDetails.

        :return: The parent_ref of this UpdateUserDefinedFunctionDetails.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this UpdateUserDefinedFunctionDetails.

        :param parent_ref: The parent_ref of this UpdateUserDefinedFunctionDetails.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this UpdateUserDefinedFunctionDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this UpdateUserDefinedFunctionDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateUserDefinedFunctionDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this UpdateUserDefinedFunctionDetails.
        :type: str
        """
        self._name = name

    @property
    def identifier(self):
        """
        Gets the identifier of this UpdateUserDefinedFunctionDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this UpdateUserDefinedFunctionDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this UpdateUserDefinedFunctionDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this UpdateUserDefinedFunctionDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def model_version(self):
        """
        Gets the model_version of this UpdateUserDefinedFunctionDetails.
        The model version of an object.


        :return: The model_version of this UpdateUserDefinedFunctionDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this UpdateUserDefinedFunctionDetails.
        The model version of an object.


        :param model_version: The model_version of this UpdateUserDefinedFunctionDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def object_version(self):
        """
        Gets the object_version of this UpdateUserDefinedFunctionDetails.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this UpdateUserDefinedFunctionDetails.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this UpdateUserDefinedFunctionDetails.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this UpdateUserDefinedFunctionDetails.
        :type: int
        """
        self._object_version = object_version

    @property
    def signatures(self):
        """
        Gets the signatures of this UpdateUserDefinedFunctionDetails.
        An array of function signature.


        :return: The signatures of this UpdateUserDefinedFunctionDetails.
        :rtype: list[oci.data_integration.models.FunctionSignature]
        """
        return self._signatures

    @signatures.setter
    def signatures(self, signatures):
        """
        Sets the signatures of this UpdateUserDefinedFunctionDetails.
        An array of function signature.


        :param signatures: The signatures of this UpdateUserDefinedFunctionDetails.
        :type: list[oci.data_integration.models.FunctionSignature]
        """
        self._signatures = signatures

    @property
    def expr(self):
        """
        Gets the expr of this UpdateUserDefinedFunctionDetails.

        :return: The expr of this UpdateUserDefinedFunctionDetails.
        :rtype: oci.data_integration.models.Expression
        """
        return self._expr

    @expr.setter
    def expr(self, expr):
        """
        Sets the expr of this UpdateUserDefinedFunctionDetails.

        :param expr: The expr of this UpdateUserDefinedFunctionDetails.
        :type: oci.data_integration.models.Expression
        """
        self._expr = expr

    @property
    def description(self):
        """
        Gets the description of this UpdateUserDefinedFunctionDetails.
        Detailed description for the object.


        :return: The description of this UpdateUserDefinedFunctionDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateUserDefinedFunctionDetails.
        Detailed description for the object.


        :param description: The description of this UpdateUserDefinedFunctionDetails.
        :type: str
        """
        self._description = description

    @property
    def object_status(self):
        """
        Gets the object_status of this UpdateUserDefinedFunctionDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this UpdateUserDefinedFunctionDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this UpdateUserDefinedFunctionDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this UpdateUserDefinedFunctionDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this UpdateUserDefinedFunctionDetails.

        :return: The registry_metadata of this UpdateUserDefinedFunctionDetails.
        :rtype: oci.data_integration.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this UpdateUserDefinedFunctionDetails.

        :param registry_metadata: The registry_metadata of this UpdateUserDefinedFunctionDetails.
        :type: oci.data_integration.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Byoipv6CidrDetails(object):
    """
    The list of one or more BYOIPv6 CIDR blocks for the VCN that meets the following criteria:
    - The CIDR must from a BYOIPv6 range.
    - The IPv6 CIDR blocks must be valid.
    - Multiple CIDR blocks must not overlap each other or the on-premises network CIDR block.
    - The number of CIDR blocks must not exceed the limit of IPv6 CIDR blocks allowed to a VCN.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Byoipv6CidrDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param byoipv6_range_id:
            The value to assign to the byoipv6_range_id property of this Byoipv6CidrDetails.
        :type byoipv6_range_id: str

        :param ipv6_cidr_block:
            The value to assign to the ipv6_cidr_block property of this Byoipv6CidrDetails.
        :type ipv6_cidr_block: str

        """
        self.swagger_types = {
            'byoipv6_range_id': 'str',
            'ipv6_cidr_block': 'str'
        }

        self.attribute_map = {
            'byoipv6_range_id': 'byoipv6RangeId',
            'ipv6_cidr_block': 'ipv6CidrBlock'
        }

        self._byoipv6_range_id = None
        self._ipv6_cidr_block = None

    @property
    def byoipv6_range_id(self):
        """
        **[Required]** Gets the byoipv6_range_id of this Byoipv6CidrDetails.
        The `OCID`__ of the `ByoipRange` resource to which the CIDR block belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The byoipv6_range_id of this Byoipv6CidrDetails.
        :rtype: str
        """
        return self._byoipv6_range_id

    @byoipv6_range_id.setter
    def byoipv6_range_id(self, byoipv6_range_id):
        """
        Sets the byoipv6_range_id of this Byoipv6CidrDetails.
        The `OCID`__ of the `ByoipRange` resource to which the CIDR block belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param byoipv6_range_id: The byoipv6_range_id of this Byoipv6CidrDetails.
        :type: str
        """
        self._byoipv6_range_id = byoipv6_range_id

    @property
    def ipv6_cidr_block(self):
        """
        **[Required]** Gets the ipv6_cidr_block of this Byoipv6CidrDetails.
        An IPv6 CIDR block required to create a VCN with a BYOIP prefix. It could be the whole CIDR block identified in `byoipv6RangeId`, or a subrange.
        Example: `2001:0db8:0123::/48`


        :return: The ipv6_cidr_block of this Byoipv6CidrDetails.
        :rtype: str
        """
        return self._ipv6_cidr_block

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, ipv6_cidr_block):
        """
        Sets the ipv6_cidr_block of this Byoipv6CidrDetails.
        An IPv6 CIDR block required to create a VCN with a BYOIP prefix. It could be the whole CIDR block identified in `byoipv6RangeId`, or a subrange.
        Example: `2001:0db8:0123::/48`


        :param ipv6_cidr_block: The ipv6_cidr_block of this Byoipv6CidrDetails.
        :type: str
        """
        self._ipv6_cidr_block = ipv6_cidr_block

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .build_run_source import BuildRunSource
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BitbucketCloudBuildRunSource(BuildRunSource):
    """
    Specifies details of build run through Bitbucket Cloud.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BitbucketCloudBuildRunSource object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.BitbucketCloudBuildRunSource.source_type` attribute
        of this class is ``BITBUCKET_CLOUD`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_type:
            The value to assign to the source_type property of this BitbucketCloudBuildRunSource.
            Allowed values for this property are: "MANUAL", "GITHUB", "GITLAB", "BITBUCKET_CLOUD", "DEVOPS_CODE_REPOSITORY"
        :type source_type: str

        :param trigger_id:
            The value to assign to the trigger_id property of this BitbucketCloudBuildRunSource.
        :type trigger_id: str

        :param trigger_info:
            The value to assign to the trigger_info property of this BitbucketCloudBuildRunSource.
        :type trigger_info: oci.devops.models.TriggerInfo

        """
        self.swagger_types = {
            'source_type': 'str',
            'trigger_id': 'str',
            'trigger_info': 'TriggerInfo'
        }

        self.attribute_map = {
            'source_type': 'sourceType',
            'trigger_id': 'triggerId',
            'trigger_info': 'triggerInfo'
        }

        self._source_type = None
        self._trigger_id = None
        self._trigger_info = None
        self._source_type = 'BITBUCKET_CLOUD'

    @property
    def trigger_id(self):
        """
        **[Required]** Gets the trigger_id of this BitbucketCloudBuildRunSource.
        The trigger that invoked the build run.


        :return: The trigger_id of this BitbucketCloudBuildRunSource.
        :rtype: str
        """
        return self._trigger_id

    @trigger_id.setter
    def trigger_id(self, trigger_id):
        """
        Sets the trigger_id of this BitbucketCloudBuildRunSource.
        The trigger that invoked the build run.


        :param trigger_id: The trigger_id of this BitbucketCloudBuildRunSource.
        :type: str
        """
        self._trigger_id = trigger_id

    @property
    def trigger_info(self):
        """
        **[Required]** Gets the trigger_info of this BitbucketCloudBuildRunSource.

        :return: The trigger_info of this BitbucketCloudBuildRunSource.
        :rtype: oci.devops.models.TriggerInfo
        """
        return self._trigger_info

    @trigger_info.setter
    def trigger_info(self, trigger_info):
        """
        Sets the trigger_info of this BitbucketCloudBuildRunSource.

        :param trigger_info: The trigger_info of this BitbucketCloudBuildRunSource.
        :type: oci.devops.models.TriggerInfo
        """
        self._trigger_info = trigger_info

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MaskingAnalyticsSummary(object):
    """
    Summary of masking analytics data.
    """

    #: A constant which can be used with the metric_name property of a MaskingAnalyticsSummary.
    #: This constant has a value of "MASKING_POLICY"
    METRIC_NAME_MASKING_POLICY = "MASKING_POLICY"

    #: A constant which can be used with the metric_name property of a MaskingAnalyticsSummary.
    #: This constant has a value of "MASKING_DATABASE"
    METRIC_NAME_MASKING_DATABASE = "MASKING_DATABASE"

    #: A constant which can be used with the metric_name property of a MaskingAnalyticsSummary.
    #: This constant has a value of "MASKING_WORK_REQUEST"
    METRIC_NAME_MASKING_WORK_REQUEST = "MASKING_WORK_REQUEST"

    #: A constant which can be used with the metric_name property of a MaskingAnalyticsSummary.
    #: This constant has a value of "MASKED_SENSITIVE_TYPE"
    METRIC_NAME_MASKED_SENSITIVE_TYPE = "MASKED_SENSITIVE_TYPE"

    #: A constant which can be used with the metric_name property of a MaskingAnalyticsSummary.
    #: This constant has a value of "MASKED_SCHEMA"
    METRIC_NAME_MASKED_SCHEMA = "MASKED_SCHEMA"

    #: A constant which can be used with the metric_name property of a MaskingAnalyticsSummary.
    #: This constant has a value of "MASKED_TABLE"
    METRIC_NAME_MASKED_TABLE = "MASKED_TABLE"

    #: A constant which can be used with the metric_name property of a MaskingAnalyticsSummary.
    #: This constant has a value of "MASKED_COLUMN"
    METRIC_NAME_MASKED_COLUMN = "MASKED_COLUMN"

    #: A constant which can be used with the metric_name property of a MaskingAnalyticsSummary.
    #: This constant has a value of "MASKED_DATA_VALUE"
    METRIC_NAME_MASKED_DATA_VALUE = "MASKED_DATA_VALUE"

    def __init__(self, **kwargs):
        """
        Initializes a new MaskingAnalyticsSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this MaskingAnalyticsSummary.
            Allowed values for this property are: "MASKING_POLICY", "MASKING_DATABASE", "MASKING_WORK_REQUEST", "MASKED_SENSITIVE_TYPE", "MASKED_SCHEMA", "MASKED_TABLE", "MASKED_COLUMN", "MASKED_DATA_VALUE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type metric_name: str

        :param dimensions:
            The value to assign to the dimensions property of this MaskingAnalyticsSummary.
        :type dimensions: oci.data_safe.models.MaskingAnalyticsDimensions

        :param count:
            The value to assign to the count property of this MaskingAnalyticsSummary.
        :type count: int

        """
        self.swagger_types = {
            'metric_name': 'str',
            'dimensions': 'MaskingAnalyticsDimensions',
            'count': 'int'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'dimensions': 'dimensions',
            'count': 'count'
        }

        self._metric_name = None
        self._dimensions = None
        self._count = None

    @property
    def metric_name(self):
        """
        **[Required]** Gets the metric_name of this MaskingAnalyticsSummary.
        The name of the aggregation metric.

        Allowed values for this property are: "MASKING_POLICY", "MASKING_DATABASE", "MASKING_WORK_REQUEST", "MASKED_SENSITIVE_TYPE", "MASKED_SCHEMA", "MASKED_TABLE", "MASKED_COLUMN", "MASKED_DATA_VALUE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The metric_name of this MaskingAnalyticsSummary.
        :rtype: str
        """
        return self._metric_name

    @metric_name.setter
    def metric_name(self, metric_name):
        """
        Sets the metric_name of this MaskingAnalyticsSummary.
        The name of the aggregation metric.


        :param metric_name: The metric_name of this MaskingAnalyticsSummary.
        :type: str
        """
        allowed_values = ["MASKING_POLICY", "MASKING_DATABASE", "MASKING_WORK_REQUEST", "MASKED_SENSITIVE_TYPE", "MASKED_SCHEMA", "MASKED_TABLE", "MASKED_COLUMN", "MASKED_DATA_VALUE"]
        if not value_allowed_none_or_none_sentinel(metric_name, allowed_values):
            metric_name = 'UNKNOWN_ENUM_VALUE'
        self._metric_name = metric_name

    @property
    def dimensions(self):
        """
        Gets the dimensions of this MaskingAnalyticsSummary.

        :return: The dimensions of this MaskingAnalyticsSummary.
        :rtype: oci.data_safe.models.MaskingAnalyticsDimensions
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """
        Sets the dimensions of this MaskingAnalyticsSummary.

        :param dimensions: The dimensions of this MaskingAnalyticsSummary.
        :type: oci.data_safe.models.MaskingAnalyticsDimensions
        """
        self._dimensions = dimensions

    @property
    def count(self):
        """
        **[Required]** Gets the count of this MaskingAnalyticsSummary.
        The total count for the aggregation metric.


        :return: The count of this MaskingAnalyticsSummary.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this MaskingAnalyticsSummary.
        The total count for the aggregation metric.


        :param count: The count of this MaskingAnalyticsSummary.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CrossConnectGroup(object):
    """
    For use with Oracle Cloud Infrastructure FastConnect. A cross-connect group
    is a link aggregation group (LAG), which can contain one or more
    :class:`CrossConnect`. Customers who are colocated with
    Oracle in a FastConnect location create and use cross-connect groups. For more
    information, see `FastConnect Overview`__.

    **Note:** If you're a provider who is setting up a physical connection to Oracle so customers
    can use FastConnect over the connection, be aware that your connection is modeled the
    same way as a colocated customer's (with `CrossConnect` and `CrossConnectGroup` objects, and so on).

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm
    __ https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a CrossConnectGroup.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a CrossConnectGroup.
    #: This constant has a value of "PROVISIONED"
    LIFECYCLE_STATE_PROVISIONED = "PROVISIONED"

    #: A constant which can be used with the lifecycle_state property of a CrossConnectGroup.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a CrossConnectGroup.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a CrossConnectGroup.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    def __init__(self, **kwargs):
        """
        Initializes a new CrossConnectGroup object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CrossConnectGroup.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CrossConnectGroup.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CrossConnectGroup.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CrossConnectGroup.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this CrossConnectGroup.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CrossConnectGroup.
            Allowed values for this property are: "PROVISIONING", "PROVISIONED", "INACTIVE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param customer_reference_name:
            The value to assign to the customer_reference_name property of this CrossConnectGroup.
        :type customer_reference_name: str

        :param time_created:
            The value to assign to the time_created property of this CrossConnectGroup.
        :type time_created: datetime

        :param macsec_properties:
            The value to assign to the macsec_properties property of this CrossConnectGroup.
        :type macsec_properties: oci.core.models.MacsecProperties

        :param oci_physical_device_name:
            The value to assign to the oci_physical_device_name property of this CrossConnectGroup.
        :type oci_physical_device_name: str

        :param oci_logical_device_name:
            The value to assign to the oci_logical_device_name property of this CrossConnectGroup.
        :type oci_logical_device_name: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'lifecycle_state': 'str',
            'customer_reference_name': 'str',
            'time_created': 'datetime',
            'macsec_properties': 'MacsecProperties',
            'oci_physical_device_name': 'str',
            'oci_logical_device_name': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'customer_reference_name': 'customerReferenceName',
            'time_created': 'timeCreated',
            'macsec_properties': 'macsecProperties',
            'oci_physical_device_name': 'ociPhysicalDeviceName',
            'oci_logical_device_name': 'ociLogicalDeviceName'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._lifecycle_state = None
        self._customer_reference_name = None
        self._time_created = None
        self._macsec_properties = None
        self._oci_physical_device_name = None
        self._oci_logical_device_name = None

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this CrossConnectGroup.
        The `OCID`__ of the compartment containing the cross-connect group.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CrossConnectGroup.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CrossConnectGroup.
        The `OCID`__ of the compartment containing the cross-connect group.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CrossConnectGroup.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CrossConnectGroup.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CrossConnectGroup.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CrossConnectGroup.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CrossConnectGroup.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CrossConnectGroup.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CrossConnectGroup.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CrossConnectGroup.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CrossConnectGroup.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CrossConnectGroup.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CrossConnectGroup.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CrossConnectGroup.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CrossConnectGroup.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        Gets the id of this CrossConnectGroup.
        The cross-connect group's Oracle ID (OCID).


        :return: The id of this CrossConnectGroup.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CrossConnectGroup.
        The cross-connect group's Oracle ID (OCID).


        :param id: The id of this CrossConnectGroup.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this CrossConnectGroup.
        The cross-connect group's current state.

        Allowed values for this property are: "PROVISIONING", "PROVISIONED", "INACTIVE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this CrossConnectGroup.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this CrossConnectGroup.
        The cross-connect group's current state.


        :param lifecycle_state: The lifecycle_state of this CrossConnectGroup.
        :type: str
        """
        allowed_values = ["PROVISIONING", "PROVISIONED", "INACTIVE", "TERMINATING", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def customer_reference_name(self):
        """
        Gets the customer_reference_name of this CrossConnectGroup.
        A reference name or identifier for the physical fiber connection that this cross-connect
        group uses.


        :return: The customer_reference_name of this CrossConnectGroup.
        :rtype: str
        """
        return self._customer_reference_name

    @customer_reference_name.setter
    def customer_reference_name(self, customer_reference_name):
        """
        Sets the customer_reference_name of this CrossConnectGroup.
        A reference name or identifier for the physical fiber connection that this cross-connect
        group uses.


        :param customer_reference_name: The customer_reference_name of this CrossConnectGroup.
        :type: str
        """
        self._customer_reference_name = customer_reference_name

    @property
    def time_created(self):
        """
        Gets the time_created of this CrossConnectGroup.
        The date and time the cross-connect group was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this CrossConnectGroup.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this CrossConnectGroup.
        The date and time the cross-connect group was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this CrossConnectGroup.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def macsec_properties(self):
        """
        Gets the macsec_properties of this CrossConnectGroup.

        :return: The macsec_properties of this CrossConnectGroup.
        :rtype: oci.core.models.MacsecProperties
        """
        return self._macsec_properties

    @macsec_properties.setter
    def macsec_properties(self, macsec_properties):
        """
        Sets the macsec_properties of this CrossConnectGroup.

        :param macsec_properties: The macsec_properties of this CrossConnectGroup.
        :type: oci.core.models.MacsecProperties
        """
        self._macsec_properties = macsec_properties

    @property
    def oci_physical_device_name(self):
        """
        Gets the oci_physical_device_name of this CrossConnectGroup.
        The FastConnect device that terminates the physical connection.


        :return: The oci_physical_device_name of this CrossConnectGroup.
        :rtype: str
        """
        return self._oci_physical_device_name

    @oci_physical_device_name.setter
    def oci_physical_device_name(self, oci_physical_device_name):
        """
        Sets the oci_physical_device_name of this CrossConnectGroup.
        The FastConnect device that terminates the physical connection.


        :param oci_physical_device_name: The oci_physical_device_name of this CrossConnectGroup.
        :type: str
        """
        self._oci_physical_device_name = oci_physical_device_name

    @property
    def oci_logical_device_name(self):
        """
        Gets the oci_logical_device_name of this CrossConnectGroup.
        The FastConnect device that terminates the logical connection.
        This device might be different than the device that terminates the physical connection.


        :return: The oci_logical_device_name of this CrossConnectGroup.
        :rtype: str
        """
        return self._oci_logical_device_name

    @oci_logical_device_name.setter
    def oci_logical_device_name(self, oci_logical_device_name):
        """
        Sets the oci_logical_device_name of this CrossConnectGroup.
        The FastConnect device that terminates the logical connection.
        This device might be different than the device that terminates the physical connection.


        :param oci_logical_device_name: The oci_logical_device_name of this CrossConnectGroup.
        :type: str
        """
        self._oci_logical_device_name = oci_logical_device_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FleetStatusByCategory(object):
    """
    The number of databases in the fleet, grouped by database type and sub type.
    """

    #: A constant which can be used with the database_type property of a FleetStatusByCategory.
    #: This constant has a value of "EXTERNAL_SIDB"
    DATABASE_TYPE_EXTERNAL_SIDB = "EXTERNAL_SIDB"

    #: A constant which can be used with the database_type property of a FleetStatusByCategory.
    #: This constant has a value of "EXTERNAL_RAC"
    DATABASE_TYPE_EXTERNAL_RAC = "EXTERNAL_RAC"

    #: A constant which can be used with the database_type property of a FleetStatusByCategory.
    #: This constant has a value of "CLOUD_SIDB"
    DATABASE_TYPE_CLOUD_SIDB = "CLOUD_SIDB"

    #: A constant which can be used with the database_type property of a FleetStatusByCategory.
    #: This constant has a value of "CLOUD_RAC"
    DATABASE_TYPE_CLOUD_RAC = "CLOUD_RAC"

    #: A constant which can be used with the database_type property of a FleetStatusByCategory.
    #: This constant has a value of "SHARED"
    DATABASE_TYPE_SHARED = "SHARED"

    #: A constant which can be used with the database_type property of a FleetStatusByCategory.
    #: This constant has a value of "DEDICATED"
    DATABASE_TYPE_DEDICATED = "DEDICATED"

    #: A constant which can be used with the database_sub_type property of a FleetStatusByCategory.
    #: This constant has a value of "CDB"
    DATABASE_SUB_TYPE_CDB = "CDB"

    #: A constant which can be used with the database_sub_type property of a FleetStatusByCategory.
    #: This constant has a value of "PDB"
    DATABASE_SUB_TYPE_PDB = "PDB"

    #: A constant which can be used with the database_sub_type property of a FleetStatusByCategory.
    #: This constant has a value of "NON_CDB"
    DATABASE_SUB_TYPE_NON_CDB = "NON_CDB"

    #: A constant which can be used with the database_sub_type property of a FleetStatusByCategory.
    #: This constant has a value of "ACD"
    DATABASE_SUB_TYPE_ACD = "ACD"

    #: A constant which can be used with the database_sub_type property of a FleetStatusByCategory.
    #: This constant has a value of "ADB"
    DATABASE_SUB_TYPE_ADB = "ADB"

    #: A constant which can be used with the deployment_type property of a FleetStatusByCategory.
    #: This constant has a value of "ONPREMISE"
    DEPLOYMENT_TYPE_ONPREMISE = "ONPREMISE"

    #: A constant which can be used with the deployment_type property of a FleetStatusByCategory.
    #: This constant has a value of "BM"
    DEPLOYMENT_TYPE_BM = "BM"

    #: A constant which can be used with the deployment_type property of a FleetStatusByCategory.
    #: This constant has a value of "VM"
    DEPLOYMENT_TYPE_VM = "VM"

    #: A constant which can be used with the deployment_type property of a FleetStatusByCategory.
    #: This constant has a value of "EXADATA"
    DEPLOYMENT_TYPE_EXADATA = "EXADATA"

    #: A constant which can be used with the deployment_type property of a FleetStatusByCategory.
    #: This constant has a value of "EXADATA_CC"
    DEPLOYMENT_TYPE_EXADATA_CC = "EXADATA_CC"

    #: A constant which can be used with the deployment_type property of a FleetStatusByCategory.
    #: This constant has a value of "AUTONOMOUS"
    DEPLOYMENT_TYPE_AUTONOMOUS = "AUTONOMOUS"

    def __init__(self, **kwargs):
        """
        Initializes a new FleetStatusByCategory object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_type:
            The value to assign to the database_type property of this FleetStatusByCategory.
            Allowed values for this property are: "EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", "SHARED", "DEDICATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_type: str

        :param database_sub_type:
            The value to assign to the database_sub_type property of this FleetStatusByCategory.
            Allowed values for this property are: "CDB", "PDB", "NON_CDB", "ACD", "ADB", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_sub_type: str

        :param deployment_type:
            The value to assign to the deployment_type property of this FleetStatusByCategory.
            Allowed values for this property are: "ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", "AUTONOMOUS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type deployment_type: str

        :param inventory_count:
            The value to assign to the inventory_count property of this FleetStatusByCategory.
        :type inventory_count: int

        """
        self.swagger_types = {
            'database_type': 'str',
            'database_sub_type': 'str',
            'deployment_type': 'str',
            'inventory_count': 'int'
        }

        self.attribute_map = {
            'database_type': 'databaseType',
            'database_sub_type': 'databaseSubType',
            'deployment_type': 'deploymentType',
            'inventory_count': 'inventoryCount'
        }

        self._database_type = None
        self._database_sub_type = None
        self._deployment_type = None
        self._inventory_count = None

    @property
    def database_type(self):
        """
        Gets the database_type of this FleetStatusByCategory.
        The type of Oracle Database installation.

        Allowed values for this property are: "EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", "SHARED", "DEDICATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_type of this FleetStatusByCategory.
        :rtype: str
        """
        return self._database_type

    @database_type.setter
    def database_type(self, database_type):
        """
        Sets the database_type of this FleetStatusByCategory.
        The type of Oracle Database installation.


        :param database_type: The database_type of this FleetStatusByCategory.
        :type: str
        """
        allowed_values = ["EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", "SHARED", "DEDICATED"]
        if not value_allowed_none_or_none_sentinel(database_type, allowed_values):
            database_type = 'UNKNOWN_ENUM_VALUE'
        self._database_type = database_type

    @property
    def database_sub_type(self):
        """
        Gets the database_sub_type of this FleetStatusByCategory.
        The subtype of the Oracle Database. Indicates whether the database is a Container Database,
        Pluggable Database, Non-container Database, Autonomous Database, or Autonomous Container Database.

        Allowed values for this property are: "CDB", "PDB", "NON_CDB", "ACD", "ADB", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_sub_type of this FleetStatusByCategory.
        :rtype: str
        """
        return self._database_sub_type

    @database_sub_type.setter
    def database_sub_type(self, database_sub_type):
        """
        Sets the database_sub_type of this FleetStatusByCategory.
        The subtype of the Oracle Database. Indicates whether the database is a Container Database,
        Pluggable Database, Non-container Database, Autonomous Database, or Autonomous Container Database.


        :param database_sub_type: The database_sub_type of this FleetStatusByCategory.
        :type: str
        """
        allowed_values = ["CDB", "PDB", "NON_CDB", "ACD", "ADB"]
        if not value_allowed_none_or_none_sentinel(database_sub_type, allowed_values):
            database_sub_type = 'UNKNOWN_ENUM_VALUE'
        self._database_sub_type = database_sub_type

    @property
    def deployment_type(self):
        """
        Gets the deployment_type of this FleetStatusByCategory.
        The infrastructure used to deploy the Oracle Database.

        Allowed values for this property are: "ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", "AUTONOMOUS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The deployment_type of this FleetStatusByCategory.
        :rtype: str
        """
        return self._deployment_type

    @deployment_type.setter
    def deployment_type(self, deployment_type):
        """
        Sets the deployment_type of this FleetStatusByCategory.
        The infrastructure used to deploy the Oracle Database.


        :param deployment_type: The deployment_type of this FleetStatusByCategory.
        :type: str
        """
        allowed_values = ["ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", "AUTONOMOUS"]
        if not value_allowed_none_or_none_sentinel(deployment_type, allowed_values):
            deployment_type = 'UNKNOWN_ENUM_VALUE'
        self._deployment_type = deployment_type

    @property
    def inventory_count(self):
        """
        Gets the inventory_count of this FleetStatusByCategory.
        The number of databases in the fleet.


        :return: The inventory_count of this FleetStatusByCategory.
        :rtype: int
        """
        return self._inventory_count

    @inventory_count.setter
    def inventory_count(self, inventory_count):
        """
        Sets the inventory_count of this FleetStatusByCategory.
        The number of databases in the fleet.


        :param inventory_count: The inventory_count of this FleetStatusByCategory.
        :type: int
        """
        self._inventory_count = inventory_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ThinAuthorizationResponse(object):
    """
    ThinAuthorizationResponse model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ThinAuthorizationResponse object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param authorization_request:
            The value to assign to the authorization_request property of this ThinAuthorizationResponse.
        :type authorization_request: oci.identity_data_plane.models.AuthorizationRequest

        :param decision_cache_duration:
            The value to assign to the decision_cache_duration property of this ThinAuthorizationResponse.
        :type decision_cache_duration: str

        """
        self.swagger_types = {
            'authorization_request': 'AuthorizationRequest',
            'decision_cache_duration': 'str'
        }

        self.attribute_map = {
            'authorization_request': 'authorizationRequest',
            'decision_cache_duration': 'decisionCacheDuration'
        }

        self._authorization_request = None
        self._decision_cache_duration = None

    @property
    def authorization_request(self):
        """
        **[Required]** Gets the authorization_request of this ThinAuthorizationResponse.
        The policy string related to the request.


        :return: The authorization_request of this ThinAuthorizationResponse.
        :rtype: oci.identity_data_plane.models.AuthorizationRequest
        """
        return self._authorization_request

    @authorization_request.setter
    def authorization_request(self, authorization_request):
        """
        Sets the authorization_request of this ThinAuthorizationResponse.
        The policy string related to the request.


        :param authorization_request: The authorization_request of this ThinAuthorizationResponse.
        :type: oci.identity_data_plane.models.AuthorizationRequest
        """
        self._authorization_request = authorization_request

    @property
    def decision_cache_duration(self):
        """
        **[Required]** Gets the decision_cache_duration of this ThinAuthorizationResponse.
        The duration of how long this decision should be cached. Note that the type is of type java.time.Duration, not
        string.


        :return: The decision_cache_duration of this ThinAuthorizationResponse.
        :rtype: str
        """
        return self._decision_cache_duration

    @decision_cache_duration.setter
    def decision_cache_duration(self, decision_cache_duration):
        """
        Sets the decision_cache_duration of this ThinAuthorizationResponse.
        The duration of how long this decision should be cached. Note that the type is of type java.time.Duration, not
        string.


        :param decision_cache_duration: The decision_cache_duration of this ThinAuthorizationResponse.
        :type: str
        """
        self._decision_cache_duration = decision_cache_duration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .target_type_tablespace_details import TargetTypeTablespaceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NonADBAutoCreateTablespaceDetails(TargetTypeTablespaceDetails):
    """
    Migration tablespace settings valid for NON-ADB target type using auto create feature.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NonADBAutoCreateTablespaceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database_migration.models.NonADBAutoCreateTablespaceDetails.target_type` attribute
        of this class is ``NON_ADB_AUTOCREATE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param target_type:
            The value to assign to the target_type property of this NonADBAutoCreateTablespaceDetails.
            Allowed values for this property are: "ADB_S_REMAP", "ADB_D_REMAP", "ADB_D_AUTOCREATE", "NON_ADB_REMAP", "NON_ADB_AUTOCREATE"
        :type target_type: str

        :param is_auto_create:
            The value to assign to the is_auto_create property of this NonADBAutoCreateTablespaceDetails.
        :type is_auto_create: bool

        :param is_big_file:
            The value to assign to the is_big_file property of this NonADBAutoCreateTablespaceDetails.
        :type is_big_file: bool

        :param extend_size_in_mbs:
            The value to assign to the extend_size_in_mbs property of this NonADBAutoCreateTablespaceDetails.
        :type extend_size_in_mbs: int

        """
        self.swagger_types = {
            'target_type': 'str',
            'is_auto_create': 'bool',
            'is_big_file': 'bool',
            'extend_size_in_mbs': 'int'
        }

        self.attribute_map = {
            'target_type': 'targetType',
            'is_auto_create': 'isAutoCreate',
            'is_big_file': 'isBigFile',
            'extend_size_in_mbs': 'extendSizeInMBs'
        }

        self._target_type = None
        self._is_auto_create = None
        self._is_big_file = None
        self._extend_size_in_mbs = None
        self._target_type = 'NON_ADB_AUTOCREATE'

    @property
    def is_auto_create(self):
        """
        Gets the is_auto_create of this NonADBAutoCreateTablespaceDetails.
        True to auto-create tablespace in the target Database.


        :return: The is_auto_create of this NonADBAutoCreateTablespaceDetails.
        :rtype: bool
        """
        return self._is_auto_create

    @is_auto_create.setter
    def is_auto_create(self, is_auto_create):
        """
        Sets the is_auto_create of this NonADBAutoCreateTablespaceDetails.
        True to auto-create tablespace in the target Database.


        :param is_auto_create: The is_auto_create of this NonADBAutoCreateTablespaceDetails.
        :type: bool
        """
        self._is_auto_create = is_auto_create

    @property
    def is_big_file(self):
        """
        Gets the is_big_file of this NonADBAutoCreateTablespaceDetails.
        True set tablespace to big file.


        :return: The is_big_file of this NonADBAutoCreateTablespaceDetails.
        :rtype: bool
        """
        return self._is_big_file

    @is_big_file.setter
    def is_big_file(self, is_big_file):
        """
        Sets the is_big_file of this NonADBAutoCreateTablespaceDetails.
        True set tablespace to big file.


        :param is_big_file: The is_big_file of this NonADBAutoCreateTablespaceDetails.
        :type: bool
        """
        self._is_big_file = is_big_file

    @property
    def extend_size_in_mbs(self):
        """
        Gets the extend_size_in_mbs of this NonADBAutoCreateTablespaceDetails.
        Size of extend in MB. Can only be specified if 'isBigFile' property is set to true.


        :return: The extend_size_in_mbs of this NonADBAutoCreateTablespaceDetails.
        :rtype: int
        """
        return self._extend_size_in_mbs

    @extend_size_in_mbs.setter
    def extend_size_in_mbs(self, extend_size_in_mbs):
        """
        Sets the extend_size_in_mbs of this NonADBAutoCreateTablespaceDetails.
        Size of extend in MB. Can only be specified if 'isBigFile' property is set to true.


        :param extend_size_in_mbs: The extend_size_in_mbs of this NonADBAutoCreateTablespaceDetails.
        :type: int
        """
        self._extend_size_in_mbs = extend_size_in_mbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_column import AbstractColumn
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ChartDataColumn(AbstractColumn):
    """
    A data series specific to a particular link output field.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ChartDataColumn object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.ChartDataColumn.type` attribute
        of this class is ``CHART_DATA_COLUMN`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this ChartDataColumn.
            Allowed values for this property are: "COLUMN", "CHART_COLUMN", "CHART_DATA_COLUMN", "TIME_COLUMN", "TREND_COLUMN", "CLASSIFY_COLUMN"
        :type type: str

        :param display_name:
            The value to assign to the display_name property of this ChartDataColumn.
        :type display_name: str

        :param sub_system:
            The value to assign to the sub_system property of this ChartDataColumn.
            Allowed values for this property are: "LOG"
        :type sub_system: str

        :param values:
            The value to assign to the values property of this ChartDataColumn.
        :type values: list[oci.log_analytics.models.FieldValue]

        :param is_list_of_values:
            The value to assign to the is_list_of_values property of this ChartDataColumn.
        :type is_list_of_values: bool

        :param is_multi_valued:
            The value to assign to the is_multi_valued property of this ChartDataColumn.
        :type is_multi_valued: bool

        :param is_case_sensitive:
            The value to assign to the is_case_sensitive property of this ChartDataColumn.
        :type is_case_sensitive: bool

        :param is_groupable:
            The value to assign to the is_groupable property of this ChartDataColumn.
        :type is_groupable: bool

        :param is_evaluable:
            The value to assign to the is_evaluable property of this ChartDataColumn.
        :type is_evaluable: bool

        :param value_type:
            The value to assign to the value_type property of this ChartDataColumn.
            Allowed values for this property are: "BOOLEAN", "STRING", "DOUBLE", "FLOAT", "LONG", "INTEGER", "TIMESTAMP", "FACET"
        :type value_type: str

        :param original_display_name:
            The value to assign to the original_display_name property of this ChartDataColumn.
        :type original_display_name: str

        :param internal_name:
            The value to assign to the internal_name property of this ChartDataColumn.
        :type internal_name: str

        :param data_items:
            The value to assign to the data_items property of this ChartDataColumn.
        :type data_items: list[object]

        :param filtered_data_items:
            The value to assign to the filtered_data_items property of this ChartDataColumn.
        :type filtered_data_items: list[object]

        """
        self.swagger_types = {
            'type': 'str',
            'display_name': 'str',
            'sub_system': 'str',
            'values': 'list[FieldValue]',
            'is_list_of_values': 'bool',
            'is_multi_valued': 'bool',
            'is_case_sensitive': 'bool',
            'is_groupable': 'bool',
            'is_evaluable': 'bool',
            'value_type': 'str',
            'original_display_name': 'str',
            'internal_name': 'str',
            'data_items': 'list[object]',
            'filtered_data_items': 'list[object]'
        }

        self.attribute_map = {
            'type': 'type',
            'display_name': 'displayName',
            'sub_system': 'subSystem',
            'values': 'values',
            'is_list_of_values': 'isListOfValues',
            'is_multi_valued': 'isMultiValued',
            'is_case_sensitive': 'isCaseSensitive',
            'is_groupable': 'isGroupable',
            'is_evaluable': 'isEvaluable',
            'value_type': 'valueType',
            'original_display_name': 'originalDisplayName',
            'internal_name': 'internalName',
            'data_items': 'dataItems',
            'filtered_data_items': 'filteredDataItems'
        }

        self._type = None
        self._display_name = None
        self._sub_system = None
        self._values = None
        self._is_list_of_values = None
        self._is_multi_valued = None
        self._is_case_sensitive = None
        self._is_groupable = None
        self._is_evaluable = None
        self._value_type = None
        self._original_display_name = None
        self._internal_name = None
        self._data_items = None
        self._filtered_data_items = None
        self._type = 'CHART_DATA_COLUMN'

    @property
    def data_items(self):
        """
        Gets the data_items of this ChartDataColumn.
        Data points for each timestamp for a specific link field un-filtered.


        :return: The data_items of this ChartDataColumn.
        :rtype: list[object]
        """
        return self._data_items

    @data_items.setter
    def data_items(self, data_items):
        """
        Sets the data_items of this ChartDataColumn.
        Data points for each timestamp for a specific link field un-filtered.


        :param data_items: The data_items of this ChartDataColumn.
        :type: list[object]
        """
        self._data_items = data_items

    @property
    def filtered_data_items(self):
        """
        Gets the filtered_data_items of this ChartDataColumn.
        Data points filtered by query string. May not contain data points for each timestamp due to filtering.


        :return: The filtered_data_items of this ChartDataColumn.
        :rtype: list[object]
        """
        return self._filtered_data_items

    @filtered_data_items.setter
    def filtered_data_items(self, filtered_data_items):
        """
        Sets the filtered_data_items of this ChartDataColumn.
        Data points filtered by query string. May not contain data points for each timestamp due to filtering.


        :param filtered_data_items: The filtered_data_items of this ChartDataColumn.
        :type: list[object]
        """
        self._filtered_data_items = filtered_data_items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceProfileRiskScoreAggregationSummary(object):
    """
    Resource profile risk score trend-line
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceProfileRiskScoreAggregationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param resource_profile_id:
            The value to assign to the resource_profile_id property of this ResourceProfileRiskScoreAggregationSummary.
        :type resource_profile_id: str

        :param resource_profile_display_name:
            The value to assign to the resource_profile_display_name property of this ResourceProfileRiskScoreAggregationSummary.
        :type resource_profile_display_name: str

        :param risk_threshold:
            The value to assign to the risk_threshold property of this ResourceProfileRiskScoreAggregationSummary.
        :type risk_threshold: int

        :param items:
            The value to assign to the items property of this ResourceProfileRiskScoreAggregationSummary.
        :type items: list[oci.cloud_guard.models.ResourceRiskScoreAggregation]

        """
        self.swagger_types = {
            'resource_profile_id': 'str',
            'resource_profile_display_name': 'str',
            'risk_threshold': 'int',
            'items': 'list[ResourceRiskScoreAggregation]'
        }

        self.attribute_map = {
            'resource_profile_id': 'resourceProfileId',
            'resource_profile_display_name': 'resourceProfileDisplayName',
            'risk_threshold': 'riskThreshold',
            'items': 'items'
        }

        self._resource_profile_id = None
        self._resource_profile_display_name = None
        self._risk_threshold = None
        self._items = None

    @property
    def resource_profile_id(self):
        """
        **[Required]** Gets the resource_profile_id of this ResourceProfileRiskScoreAggregationSummary.
        OCID for the resource profile


        :return: The resource_profile_id of this ResourceProfileRiskScoreAggregationSummary.
        :rtype: str
        """
        return self._resource_profile_id

    @resource_profile_id.setter
    def resource_profile_id(self, resource_profile_id):
        """
        Sets the resource_profile_id of this ResourceProfileRiskScoreAggregationSummary.
        OCID for the resource profile


        :param resource_profile_id: The resource_profile_id of this ResourceProfileRiskScoreAggregationSummary.
        :type: str
        """
        self._resource_profile_id = resource_profile_id

    @property
    def resource_profile_display_name(self):
        """
        **[Required]** Gets the resource_profile_display_name of this ResourceProfileRiskScoreAggregationSummary.
        Display name for the resource profile


        :return: The resource_profile_display_name of this ResourceProfileRiskScoreAggregationSummary.
        :rtype: str
        """
        return self._resource_profile_display_name

    @resource_profile_display_name.setter
    def resource_profile_display_name(self, resource_profile_display_name):
        """
        Sets the resource_profile_display_name of this ResourceProfileRiskScoreAggregationSummary.
        Display name for the resource profile


        :param resource_profile_display_name: The resource_profile_display_name of this ResourceProfileRiskScoreAggregationSummary.
        :type: str
        """
        self._resource_profile_display_name = resource_profile_display_name

    @property
    def risk_threshold(self):
        """
        Gets the risk_threshold of this ResourceProfileRiskScoreAggregationSummary.
        Risk threshold


        :return: The risk_threshold of this ResourceProfileRiskScoreAggregationSummary.
        :rtype: int
        """
        return self._risk_threshold

    @risk_threshold.setter
    def risk_threshold(self, risk_threshold):
        """
        Sets the risk_threshold of this ResourceProfileRiskScoreAggregationSummary.
        Risk threshold


        :param risk_threshold: The risk_threshold of this ResourceProfileRiskScoreAggregationSummary.
        :type: int
        """
        self._risk_threshold = risk_threshold

    @property
    def items(self):
        """
        **[Required]** Gets the items of this ResourceProfileRiskScoreAggregationSummary.
        List of ResourceRiskScoreAggregation


        :return: The items of this ResourceProfileRiskScoreAggregationSummary.
        :rtype: list[oci.cloud_guard.models.ResourceRiskScoreAggregation]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this ResourceProfileRiskScoreAggregationSummary.
        List of ResourceRiskScoreAggregation


        :param items: The items of this ResourceProfileRiskScoreAggregationSummary.
        :type: list[oci.cloud_guard.models.ResourceRiskScoreAggregation]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDeletionPolicyDetails(object):
    """
    Policy for how the DB System and related resources should be handled at the time of its deletion.
    """

    #: A constant which can be used with the automatic_backup_retention property of a CreateDeletionPolicyDetails.
    #: This constant has a value of "DELETE"
    AUTOMATIC_BACKUP_RETENTION_DELETE = "DELETE"

    #: A constant which can be used with the automatic_backup_retention property of a CreateDeletionPolicyDetails.
    #: This constant has a value of "RETAIN"
    AUTOMATIC_BACKUP_RETENTION_RETAIN = "RETAIN"

    #: A constant which can be used with the final_backup property of a CreateDeletionPolicyDetails.
    #: This constant has a value of "SKIP_FINAL_BACKUP"
    FINAL_BACKUP_SKIP_FINAL_BACKUP = "SKIP_FINAL_BACKUP"

    #: A constant which can be used with the final_backup property of a CreateDeletionPolicyDetails.
    #: This constant has a value of "REQUIRE_FINAL_BACKUP"
    FINAL_BACKUP_REQUIRE_FINAL_BACKUP = "REQUIRE_FINAL_BACKUP"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDeletionPolicyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param automatic_backup_retention:
            The value to assign to the automatic_backup_retention property of this CreateDeletionPolicyDetails.
            Allowed values for this property are: "DELETE", "RETAIN"
        :type automatic_backup_retention: str

        :param final_backup:
            The value to assign to the final_backup property of this CreateDeletionPolicyDetails.
            Allowed values for this property are: "SKIP_FINAL_BACKUP", "REQUIRE_FINAL_BACKUP"
        :type final_backup: str

        :param is_delete_protected:
            The value to assign to the is_delete_protected property of this CreateDeletionPolicyDetails.
        :type is_delete_protected: bool

        """
        self.swagger_types = {
            'automatic_backup_retention': 'str',
            'final_backup': 'str',
            'is_delete_protected': 'bool'
        }

        self.attribute_map = {
            'automatic_backup_retention': 'automaticBackupRetention',
            'final_backup': 'finalBackup',
            'is_delete_protected': 'isDeleteProtected'
        }

        self._automatic_backup_retention = None
        self._final_backup = None
        self._is_delete_protected = None

    @property
    def automatic_backup_retention(self):
        """
        Gets the automatic_backup_retention of this CreateDeletionPolicyDetails.
        Specifies if any automatic backups created for a DB System should be retained or deleted when the DB System is deleted.

        Allowed values for this property are: "DELETE", "RETAIN"


        :return: The automatic_backup_retention of this CreateDeletionPolicyDetails.
        :rtype: str
        """
        return self._automatic_backup_retention

    @automatic_backup_retention.setter
    def automatic_backup_retention(self, automatic_backup_retention):
        """
        Sets the automatic_backup_retention of this CreateDeletionPolicyDetails.
        Specifies if any automatic backups created for a DB System should be retained or deleted when the DB System is deleted.


        :param automatic_backup_retention: The automatic_backup_retention of this CreateDeletionPolicyDetails.
        :type: str
        """
        allowed_values = ["DELETE", "RETAIN"]
        if not value_allowed_none_or_none_sentinel(automatic_backup_retention, allowed_values):
            raise ValueError(
                "Invalid value for `automatic_backup_retention`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._automatic_backup_retention = automatic_backup_retention

    @property
    def final_backup(self):
        """
        Gets the final_backup of this CreateDeletionPolicyDetails.
        Specifies whether or not a backup is taken when the DB System is deleted.
          REQUIRE_FINAL_BACKUP: a backup is taken if the DB System is deleted.
          SKIP_FINAL_BACKUP: a backup is not taken if the DB System is deleted.

        Allowed values for this property are: "SKIP_FINAL_BACKUP", "REQUIRE_FINAL_BACKUP"


        :return: The final_backup of this CreateDeletionPolicyDetails.
        :rtype: str
        """
        return self._final_backup

    @final_backup.setter
    def final_backup(self, final_backup):
        """
        Sets the final_backup of this CreateDeletionPolicyDetails.
        Specifies whether or not a backup is taken when the DB System is deleted.
          REQUIRE_FINAL_BACKUP: a backup is taken if the DB System is deleted.
          SKIP_FINAL_BACKUP: a backup is not taken if the DB System is deleted.


        :param final_backup: The final_backup of this CreateDeletionPolicyDetails.
        :type: str
        """
        allowed_values = ["SKIP_FINAL_BACKUP", "REQUIRE_FINAL_BACKUP"]
        if not value_allowed_none_or_none_sentinel(final_backup, allowed_values):
            raise ValueError(
                "Invalid value for `final_backup`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._final_backup = final_backup

    @property
    def is_delete_protected(self):
        """
        Gets the is_delete_protected of this CreateDeletionPolicyDetails.
        Specifies whether the DB System can be deleted. Set to true to prevent deletion, false (default) to allow.


        :return: The is_delete_protected of this CreateDeletionPolicyDetails.
        :rtype: bool
        """
        return self._is_delete_protected

    @is_delete_protected.setter
    def is_delete_protected(self, is_delete_protected):
        """
        Sets the is_delete_protected of this CreateDeletionPolicyDetails.
        Specifies whether the DB System can be deleted. Set to true to prevent deletion, false (default) to allow.


        :param is_delete_protected: The is_delete_protected of this CreateDeletionPolicyDetails.
        :type: bool
        """
        self._is_delete_protected = is_delete_protected

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
